@@ -19,11 +19,10 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-"""Formats Python code (using autoflake, autopep8, docformatter, etc.)."""
+"""Formats Python code to follow a consistent style."""
 
 from __future__ import print_function
 
-import errno
 import io
 
 import autoflake
@@ -32,7 +31,7 @@ import docformatter
 import unify
 
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 
 try:
@@ -87,12 +86,10 @@ def format_file(filename, args, standard_out):
                                              encoding=encoding) as output_file:
                 output_file.write(formatted_source)
         else:
-            import difflib
-            diff = difflib.unified_diff(
+            diff = autoflake.get_diff_text(
                 io.StringIO(source).readlines(),
                 io.StringIO(formatted_source).readlines(),
-                'before/' + filename,
-                'after/' + filename)
+                filename)
             standard_out.write(unicode().join(diff))
 
 
@@ -106,8 +103,6 @@ def _format_file(parameters):
     try:
         format_file(*parameters[:-1])
     except IOError as exception:
-        if exception.errno == errno.EPIPE:
-            raise
         print(unicode(exception), file=standard_error)
 
 
@@ -119,20 +114,15 @@ def format_multiple_files(filenames, args, standard_out, standard_error):
     """
     filenames = autopep8.find_files(list(filenames),
                                     args.recursive, args.exclude)
-    try:
-        if args.jobs > 1:
-            import multiprocessing
-            pool = multiprocessing.Pool(args.jobs)
-            pool.map(_format_file,
-                     [(name, args, standard_out, standard_error)
-                      for name in filenames])
-        else:
-            for name in filenames:
-                _format_file((name, args, standard_out, standard_error))
-    except IOError as exception:
-        # Ignore broken pipe.
-        if exception.errno == errno.EPIPE:
-            pass
+    if args.jobs > 1:
+        import multiprocessing
+        pool = multiprocessing.Pool(args.jobs)
+        pool.map(_format_file,
+                 [(name, args, standard_out, standard_error)
+                  for name in filenames])
+    else:
+        for name in filenames:
+            _format_file((name, args, standard_out, standard_error))
 
 
 def parse_args(argv):
